Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccessLevel ¶
type AccessLevel uint8
const ( Unknown AccessLevel = iota RO RW ADMIN )
func (AccessLevel) MarshalGQL ¶
func (a AccessLevel) MarshalGQL(w io.Writer)
func (*AccessLevel) Scan ¶
func (a *AccessLevel) Scan(src any) error
func (AccessLevel) String ¶
func (a AccessLevel) String() string
func (AccessLevel) UnmarshalGQL ¶
func (a AccessLevel) UnmarshalGQL(v any) error
func (AccessLevel) Values ¶
func (a AccessLevel) Values() []string
type FileEntry ¶
type FileEntry struct {
ID uuid.UUID
BucketID uuid.UUID
ObjectId *uuid.UUID
Name string
IsDirectory bool
Tags []string
}
FileEntry is an entry in a tree it refers to an object that is stored in the filesystem the same object might be referenced by multiple entries
type FileObject ¶
type FileObject struct {
ID uuid.UUID
BucketID uuid.UUID
Hash []byte
MimeType string
Size int64
StorageKey string
}
FileObject represents the actual data that is stored on some file system backend
type InviteToken ¶
type InviteToken []byte
func (InviteToken) String ¶
func (t InviteToken) String() string
type UserInvite ¶
type UserInvite struct {
Invitee uuid.UUID
Admin bool
Token InviteToken
}
Click to show internal directories.
Click to hide internal directories.